==> 0.0.3.tar.gz: lib/Chatroom/PIA_Chatroom.dart <==

import 'dart:io';

import 'package:dio/src/dio_error.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:pia_framework/API/PIA_API_Background.dart';
import 'package:pia_framework/API/PIA_API_Popup.dart';
import 'package:pia_framework/API/PIA_API_Widget.dart';
import 'package:pia_framework/Variable/PIA_Global.dart';
import 'package:pia_framework/View/PIA_Page.dart';
import 'package:pia_framework/Image/PIA_PhotoView.dart';
import 'package:pia_framework/View/PIA_WebPage.dart';
import 'package:pia_framework/Form/PIA_Form.dart';
import 'package:pia_framework/Image/PIA_Image.dart';
import 'package:pia_framework/Image/PIA_ImagePicker.dart';
import 'package:pia_framework/Lang/PIA_Lang.dart';

class PIA_Chatroom_CallBack
{    Widget Chat_item(BuildContext context,Map<String,dynamic> sdata) {} }

// example for callback
// return new Padding(padding: EdgeInsets.all(0),
//      child: new ListTile(
//      //leading: PIA_Image("Asset/Image/company.png",50,50,0,BoxFit.cover),
//      title: new Text(sdata["api"],style:new TextStyle(color: (sdata["isclick"] == "1" ) ? Colors.blue : Colors.pink)),
//      subtitle: (sdata["isclick"] == "1") ? PIA_Image("Asset/Image/company.png",150,150,0,BoxFit.cover): null,
//          onTap: (){
//        if(sdata["isclick"] != "1")
//          {  sdata["isclick"] = "1"; }
//         else
//          {  sdata["isclick"] = ""; }
//
//        updatestate(null);
//      },
//    ));

class PIA_Chatroom_Controller {
  _PIA_Chatroom_State State;
  update() {
    State.sound = true;
    State.Update();
  }
}


class PIA_Chatroom extends StatefulWidget
{   String chat_url;
    String Send_message_url;
    String Send_Photo_url;
    bool hasfile = false;

    Map<String,String> post = Map<String,String>();
    PIA_Chatroom_CallBack callback;
    PIA_Chatroom_Controller controller;

    PIA_Chatroom({this.chat_url,this.Send_message_url,this.Send_Photo_url, this.post, this.callback,this.controller,this.hasfile});
   _PIA_Chatroom_State createState()
     { print("Create Chat State");
       return _PIA_Chatroom_State(); }
}


// #docregion print-state
class _PIA_Chatroom_State extends State<PIA_Chatroom> implements PIA_API_CallBack, PIA_ImagePicker_CallBack{
  ScrollController _controller;
  bool firstload = true;
  PIA_Form form = PIA_Form(TextStyle(fontSize: 12), Colors.black26, 5);
  String last_id = "0";
  BuildContext _context;
  bool update_data = false;
  bool sound = false;

  final items = new List<Map<String,dynamic>>();

  void initState() {
    _controller = ScrollController();
    widget.controller.State = this;

    if(widget.post == null)
      { print("Set Widget post ");
        widget.post = Map<String,String>(); }
  }


  @override
  Widget build(BuildContext context) {
    print("PIA_Chatroom Build Now");
    print(widget.chat_url + " : Post : " + widget.post.toString());

    _context = context;
    if (firstload) {
       return PIA_API_Widget(url:widget.chat_url,post:widget.post,callback:this);
    }
    else
    {  return Column(
        children: <Widget>[
         Expanded(child:Chat_Body(context)),
         Divider(height: 1,color: Colors.black26,),
         Container(
           color: Colors.grey.withOpacity(0.1),
           child:Default_input(context),
         )
        ],
      );
    }
  }

  Widget Chat_Body(BuildContext context) {
    return ListView.builder(itemCount: items.length,
        padding: EdgeInsets.all(10.0),
        controller: _controller,
        reverse: true,
        itemBuilder: (context, index) {
          if (widget.callback != null) {
            return widget.callback.Chat_item(context,items[index]);
          }
          else {
            return Default_item(context,items[index]);
          }
        });
  }


  Widget Default_input(BuildContext context)
  {  return Row(
     crossAxisAlignment: CrossAxisAlignment.start,
     children: <Widget>[
       Padding(
         padding: const EdgeInsets.only(top:3.0),
         child: IconButton(icon: Icon(Icons.photo),onPressed: () { Get_photo(context);}),
       ),
       Expanded(child:form.text_chatmessage("message",500)),
       Padding(
         padding: const EdgeInsets.only(top:3.0),
         child: IconButton(icon: Icon(Icons.send),onPressed:(){ Send_Message();}),
       ),
    ],
   );
  }


  Widget Default_item(BuildContext context,Map<String,dynamic> json)
  {  if(json["type"] == 1)
      {  return Padding(
          padding: EdgeInsets.all(10),
          child:
          Column(
            crossAxisAlignment: CrossAxisAlignment.end,
            children: <Widget>[
              (json["photo"].toString().isEmpty) ?
              ClipRRect(
                  borderRadius: BorderRadius.circular(10.0),
                  child: Container(
                    padding: EdgeInsets.all(10.0),

                    child:Text(json["message"].toString(),style: TextStyle(color:Colors.black),),
                    color: Colors.grey,
                    constraints: BoxConstraints(
                      maxWidth: 300,
                    ),
                  ))
                  :
              GestureDetector(
                  onTap: () {
                    //PIA_Page.new_page(context, PIA_WebPage(title:lang_photo[PIA_Lang.lang_id],url:json["photo"].toString()));
                    PIA_Page.new_page(context,PIA_PhotoView(url:json["photo"].toString()));
                  },
                  child: PIA_Image(image_path:json["photo"].toString(),
                    width:200,
                    height:200,
                    round:10,
                    boxfit:BoxFit.cover,
                  )
              ),

              Text(json["time"]),
            ],
          )
      );

    }
    else
    {
        return Padding(
            padding: EdgeInsets.all(10),
            child:
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
            (json["photo"].toString().isEmpty) ?
                ClipRRect(
            borderRadius: BorderRadius.circular(10.0),
            child: Container(
              padding: EdgeInsets.all(10.0),

              child:Text(json["message"].toString(),style: TextStyle(color:Colors.white),),
              color: Colors.blueAccent,
              constraints: BoxConstraints(
                maxWidth: 300,
                ),
              ))
             :
        GestureDetector(
            onTap: () {
              //PIA_Page.new_page(context, PIA_WebPage(title:lang_photo[PIA_Lang.lang_id],url:json["photo"].toString()));
              PIA_Page.new_page(context,PIA_PhotoView(url:json["photo"].toString()));
            },
            child: PIA_Image(image_path:json["photo"].toString(),
              width:200,
              height:200,
              round:10,
              boxfit:BoxFit.cover,
            )
        ),

        Text(json["time"]),
              ],
            )
          );

      }
  }

  void Update()
  {  PIA_API_Background.Post(widget.chat_url,widget.post,this);  }

  void Get_photo(BuildContext context)
  {  print("Get Photo");
     PIA_ImagePicker.show_bottom_sheet(context,this,false,1000,widget.hasfile);
  }

  void Send_Message() {
     print("Send Message");
     sound = false;
     widget.post["message"] = form.get("message").toString();
     widget.post["last_id"] = last_id;
     PIA_API_Popup.Post(_context, widget.Send_message_url,widget.post,this);
  }

  @override
  void API_Error(DioErrorType error) {
    // TODO: implement API_Error
  }

  @override
  void API_Success(Map<String, dynamic > json, List j) {
    print("Load Success");
    if(last_id == json["last_id"]) { return; }

    firstload = false;
    last_id = json["last_id"];
    setState(() {
      j.forEach((dynamic value) {
        items.insert(0, value);
      });
    });
    _controller.animateTo(0.0, duration: Duration(milliseconds: 300), curve: Curves.easeOut);
    if(sound)
       { SystemSound.play(SystemSoundType.click); }
    sound = false;
  }

  @override
  void API_Upload_prodcess(int upload, int total) {
    // TODO: implement API_Upload_prodcess
  }

  @override
  void Image_Picker_Callback(File image) {
    // TODO: implement Image_Picker_Callback
    sound = false;
    widget.post["last_id"] = last_id;
    PIA_API_Popup.Upload(_context, widget.Send_Photo_url,widget.post,{"photo":image},this);
  }


}

==> 0.0.5.tar.gz: lib/Chatroom/PIA_Chatroom.dart <==

import 'dart:io';

import 'package:dio/src/dio_error.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:pia_framework/API/PIA_API_Background.dart';
import 'package:pia_framework/API/PIA_API_Popup.dart';
import 'package:pia_framework/API/PIA_API_Widget.dart';
import 'package:pia_framework/Variable/PIA_Global.dart';
import 'package:pia_framework/View/PIA_Page.dart';
import 'package:pia_framework/Image/PIA_PhotoView.dart';
import 'package:pia_framework/View/PIA_WebPage.dart';
import 'package:pia_framework/Form/PIA_Form.dart';
import 'package:pia_framework/Image/PIA_Image.dart';
import 'package:pia_framework/Image/PIA_ImagePicker.dart';
import 'package:pia_framework/Lang/PIA_Lang.dart';

class PIA_Chatroom_CallBack
{    Widget Chat_item(BuildContext context,Map<String,dynamic> sdata) {} }

// example for callback
// return new Padding(padding: EdgeInsets.all(0),
//      child: new ListTile(
//      //leading: PIA_Image("Asset/Image/company.png",50,50,0,BoxFit.cover),
//      title: new Text(sdata["api"],style:new TextStyle(color: (sdata["isclick"] == "1" ) ? Colors.blue : Colors.pink)),
//      subtitle: (sdata["isclick"] == "1") ? PIA_Image("Asset/Image/company.png",150,150,0,BoxFit.cover): null,
//          onTap: (){
//        if(sdata["isclick"] != "1")
//          {  sdata["isclick"] = "1"; }
//         else
//          {  sdata["isclick"] = ""; }
//
//        updatestate(null);
//      },
//    ));

class PIA_Chatroom_Controller {
  _PIA_Chatroom_State State;
  update() {
    State.sound = true;
    State.Update();
  }
}


class PIA_Chatroom extends StatefulWidget
{   String chat_url;
    String Send_message_url;
    String Send_Photo_url;
    bool hasfile = false;

    Map<String,String> post = Map<String,String>();
    PIA_Chatroom_CallBack callback;
    PIA_Chatroom_Controller controller;

    PIA_Chatroom({this.chat_url,this.Send_message_url,this.Send_Photo_url, this.post, this.callback,this.controller,this.hasfile});
   _PIA_Chatroom_State createState()
     { print("Create Chat State");
       return _PIA_Chatroom_State(); }
}


// #docregion print-state
class _PIA_Chatroom_State extends State<PIA_Chatroom> implements PIA_API_CallBack, PIA_ImagePicker_CallBack{
  ScrollController _controller;
  bool firstload = true;
  PIA_Form form = PIA_Form(TextStyle(fontSize: 12), Colors.black26, 5);
  String last_id = "0";
  BuildContext _context;
  bool update_data = false;
  bool sound = false;

  final items = new List<Map<String,dynamic>>();

  void initState() {
    _controller = ScrollController();
    widget.controller.State = this;

    if(widget.post == null)
      { print("Set Widget post ");
        widget.post = Map<String,String>(); }
  }


  @override
  Widget build(BuildContext context) {
    print("PIA_Chatroom Build Now");
    print(widget.chat_url + " : Post : " + widget.post.toString());

    _context = context;
    if (firstload) {
       return PIA_API_Widget(url:widget.chat_url,post:widget.post,callback:this);
    }
    else
    {  return Column(
        children: <Widget>[
         Expanded(child:Chat_Body(context)),
         Divider(height: 1,color: Colors.black26,),
         Container(
           color: Colors.grey.withOpacity(0.1),
           child:Default_input(context),
         )
        ],
      );
    }
  }

  Widget Chat_Body(BuildContext context) {
    return ListView.builder(itemCount: items.length,
        padding: EdgeInsets.all(10.0),
        controller: _controller,
        reverse: true,
        itemBuilder: (context, index) {
          if (widget.callback != null) {
            return widget.callback.Chat_item(context,items[index]);
          }
          else {
            return Default_item(context,items[index]);
          }
        });
  }


  Widget Default_input(BuildContext context)
  {  return Row(
     crossAxisAlignment: CrossAxisAlignment.start,
     children: <Widget>[
       Padding(
         padding: const EdgeInsets.only(top:3.0),
         child: IconButton(icon: Icon(Icons.photo),onPressed: () { Get_photo(context);}),
       ),
       Expanded(child:form.text_chatmessage("message",500)),
       Padding(
         padding: const EdgeInsets.only(top:3.0),
         child: IconButton(icon: Icon(Icons.send),onPressed:(){ Send_Message();}),
       ),
    ],
   );
  }


  Widget Default_item(BuildContext context,Map<String,dynamic> json)
  {  if(json["type"] == 1)
      {  return Padding(
          padding: EdgeInsets.all(10),
          child:
          Column(
            crossAxisAlignment: CrossAxisAlignment.end,
            children: <Widget>[
              (json["photo"].toString().isEmpty) ?
              ClipRRect(
                  borderRadius: BorderRadius.circular(10.0),
                  child: Container(
                    padding: EdgeInsets.all(10.0),

                    child:Text(json["message"].toString(),style: TextStyle(color:Colors.black),),
                    color: Colors.grey,
                    constraints: BoxConstraints(
                      maxWidth: 300,
                    ),
                  ))
                  :
              GestureDetector(
                  onTap: () {
                    //PIA_Page.new_page(context, PIA_WebPage(title:lang_photo[PIA_Lang.lang_id],url:json["photo"].toString()));
                    PIA_Page.new_page(context,PIA_PhotoView(url:json["photo"].toString()));
                  },
                  child: PIA_Image(json["photo"].toString(),200,200,10,BoxFit.cover)
              ),

              Text(json["time"]),
            ],
          )
      );

    }
    else
    {
        return Padding(
            padding: EdgeInsets.all(10),
            child:
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
            (json["photo"].toString().isEmpty) ?
                ClipRRect(
            borderRadius: BorderRadius.circular(10.0),
            child: Container(
              padding: EdgeInsets.all(10.0),

              child:Text(json["message"].toString(),style: TextStyle(color:Colors.white),),
              color: Colors.blueAccent,
              constraints: BoxConstraints(
                maxWidth: 300,
                ),
              ))
             :
        GestureDetector(
            onTap: () {
              //PIA_Page.new_page(context, PIA_WebPage(title:lang_photo[PIA_Lang.lang_id],url:json["photo"].toString()));
              PIA_Page.new_page(context,PIA_PhotoView(url:json["photo"].toString()));
            },
            child: PIA_Image(json["photo"].toString(),200,200,10,BoxFit.cover)
        ),

        Text(json["time"]),
              ],
            )
          );

      }
  }

  void Update()
  {  PIA_API_Background.Post(widget.chat_url,widget.post,this);  }

  void Get_photo(BuildContext context)
  {  print("Get Photo");
     PIA_ImagePicker.show_bottom_sheet(context,this,false,1000,widget.hasfile);
  }

  void Send_Message() {
     print("Send Message");
     sound = false;
     widget.post["message"] = form.get("message").toString();
     widget.post["last_id"] = last_id;
     PIA_API_Popup.Post(_context, widget.Send_message_url,widget.post,this);
  }

  @override
  void API_Error(DioErrorType error) {
    // TODO: implement API_Error
  }

  @override
  void API_Success(Map<String, dynamic > json, List j) {
    print("Load Success");
    if(last_id == json["last_id"]) { return; }

    firstload = false;
    last_id = json["last_id"];
    setState(() {
      j.forEach((dynamic value) {
        items.insert(0, value);
      });
    });
    _controller.animateTo(0.0, duration: Duration(milliseconds: 300), curve: Curves.easeOut);
    if(sound)
       { SystemSound.play(SystemSoundType.click); }
    sound = false;
  }

  @override
  void API_Upload_prodcess(int upload, int total) {
    // TODO: implement API_Upload_prodcess
  }

  @override
  void Image_Picker_Callback(File image) {
    // TODO: implement Image_Picker_Callback
    sound = false;
    widget.post["last_id"] = last_id;
    PIA_API_Popup.Upload(_context, widget.Send_Photo_url,widget.post,{"photo":image},this);
  }


}
